@@ -519,9 +519,10 @@ class WindowsUtil:
         win32api.keybd_event(17, 0, win32con.KEYEVENTF_KEYUP, 0)
 
     def write(self, data):
-        length = win32gui.GetWindowTextLength(self.handle)
-        win32gui.SendMessage(self.handle, win32con.EM_SETSEL, length, length)
-        win32gui.SendMessage(self.handle, win32con.EM_REPLACESEL, False, data)
+        handle = win32gui.GetForegroundWindow() # 获取当前最靠前并且是激活得窗口 不用传参数
+        # title = win32gui.GetWindowText(handle)  # 获取标题
+        # clsname = win32gui.GetClassName(handle) # 获取类名
+        win32gui.SendMessage(handle, win32con.WM_SETTEXT, None, data)
 
     def get_new_file_name(self, path, file_name):
         '''
@@ -575,7 +576,7 @@ class WindowsUtil:
         scanoutput_list = popen_close(cmd)
         current_authentication = ''
         for i in scanoutput_list:
-            if '身份验证' in i:
+            if '身份验证' in i or 'Authentication' in i:
                 current_authentication = i
                 break
         current_authentication = current_authentication.split(':')[1].replace('\n', '').replace('\r', '').strip()
@@ -597,7 +598,7 @@ class WindowsUtil:
         currentSSID_password_all_info_list = popen_close(cmd)
         currentSSID_password = ''
         for i in currentSSID_password_all_info_list:
-            if '关键内容' in i:
+            if '关键内容' in i or 'Key Content' in i:
                 currentSSID_password = i
                 break
         if currentSSID_password:
